[Cmake-commits] CMake branch, next, updated. v2.8.7-2068-g699094b

Eric Noulard eric.noulard at gmail.com
Wed Jan 11 09:55:05 EST 2012


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  699094b3ceb919095860626784e1f9fc9e1397e2 (commit)
       via  c5f4bf565611be0f737e3331ce92f9473aff5585 (commit)
      from  8c508d230187b6f03a38b53220717989d08f4d82 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=699094b3ceb919095860626784e1f9fc9e1397e2
commit 699094b3ceb919095860626784e1f9fc9e1397e2
Merge: 8c508d2 c5f4bf5
Author:     Eric Noulard <eric.noulard at gmail.com>
AuthorDate: Wed Jan 11 09:54:26 2012 -0500
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Wed Jan 11 09:54:26 2012 -0500

    Merge topic 'fixSymlinkInZIP' into next
    
    c5f4bf5 Fix regression on TarTest


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c5f4bf565611be0f737e3331ce92f9473aff5585
commit c5f4bf565611be0f737e3331ce92f9473aff5585
Author:     Eric NOULARD <eric.noulard at gmail.com>
AuthorDate: Wed Jan 11 15:51:42 2012 +0100
Commit:     Eric NOULARD <eric.noulard at gmail.com>
CommitDate: Wed Jan 11 15:51:42 2012 +0100

    Fix regression on TarTest

diff --git a/Source/cmArchiveWrite.cxx b/Source/cmArchiveWrite.cxx
index e3f2299..e8fc45a 100644
--- a/Source/cmArchiveWrite.cxx
+++ b/Source/cmArchiveWrite.cxx
@@ -247,8 +247,8 @@ bool cmArchiveWrite::AddFile(const char* file,
     return false;
     }
 
-  // do not copy content of symlink
-  if (!(archive_entry_filetype(e) & AE_IFLNK))
+  // do not copy content of symlink for ZIP format
+  if ((archive_format(this->Archive)!=ARCHIVE_FORMAT_ZIP) || (!(archive_entry_filetype(e) & AE_IFLNK)))
     {
     // Content.
     if(size_t size = static_cast<size_t>(archive_entry_size(e)))

-----------------------------------------------------------------------

Summary of changes:
 Source/cmArchiveWrite.cxx |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake


More information about the Cmake-commits mailing list